# Pagination Navigation

> Quick first, previous, next, last, and page buttons for navigation based pagination, supporting
> regular links or router links.

`<b-pagination-nav>` is used for navigating to new page URLs. For controlling in page component
pagination (such as table or list pagination), use the
[`<b-pagination>`](/docs/components/pagination) component instead.

```html
<template>
  <div class="overflow-auto">
    <div>
      <h6>Default</h6>
      <b-pagination-nav base-url="#" :number-of-pages="10" v-model="currentPage" />
    </div>

    <div class="mt-3">
      <h6 class="mt-4">With link generator function</h6>
      <b-pagination-nav :link-gen="linkGen" :number-of-pages="10" v-model="currentPage" />
    </div>

    <div class="mt-3">Current Page: {{ currentPage }}</div>
  </div>
</template>

<script>
  export default {
    data() {
      return {
        currentPage: 1
      }
    },
    methods: {
      linkGen(pageNum) {
        return '#page/' + pageNum + '/foobar'
      }
    }
  }
</script>

<!-- b-pagination-nav.vue -->
```

`<b-pagination-nav>` is a custom input component that provides navigational pagination. The current
page should be set via the `value` prop (or `v-model`), and the total number of pages set with
`number-of-pages`. Page numbers are indexed from 1 through `number-of-pages`.

## Current page

You should **always** set the current page number by setting the prop `value` (or using `v-model`)
to ensure that correct active page number is highlighted.

## Link generation

By default, `<b-pagination-nav>` generates plain link tags, setting the HREF attribute to `base-url`
concatenated with the page number. The `base-url` prop defaults to '/'.

### Router links

To generate page links as [`<router link>`](https://router.vuejs.org/en/api/router-link.html)
components, set the `use-router` prop. The HREF will then become the `to` prop of the router link.

### Link Generator function

If you need finer grained control over the generated link URLs or `<router-link>` `to` props, you
may set the `link-gen` prop to a function reference that accepts one argument which is a page
number. The `link-gen` function should return either a string (for HREF) or a router `to` object. If
the returned value is an object, then a router-link will always be generated. If the return value is
a string, a link is generated by default unless the `use-router` prop is set.

```js
// For regular HREF (or string `to` prop if `use-router` is set)
linkGen(pageNum) {
  return '/foo/page/' + pageNum
}

// Returning a router-link `to` object
linkGen(pageNum) {
  return {
    path: '/foo/page/' + pageNum
  }
}
```

### Page number generation

By default, `<b-pagination-nav>` renders page numbers (1-N) in the page link buttons. You can
override this behaviour by supplying a function reference to the `page-gen` property. The function
reference should accept a single argument which is a page number (1-N). The `page-gen` function
should return a string.

**Note:** HTML content in generated page number strings is **not** supported.

**Example: Using an array of links to generate pagination:**

```html
<template>
  <div class="overflow-auto">
    <b-pagination-nav
      :link-gen="linkGen"
      :page-gen="pageGen"
      :number-of-pages="links.length"
      v-model="currentPage"
    />

    <div class="mt-3">
      Page: {{ currentPage }}<br />
      Page Link: {{ pageLink }}
    </div>
  </div>
</template>

<script>
  export default {
    computed: {
      pageLink() {
        return this.linkGen(this.currentPage)
      }
    },
    data() {
      return {
        currentPage: 1,
        links: ['#foo', '#bar', '#baz', '#faz']
      }
    },
    methods: {
      linkGen(pageNum) {
        return this.links[pageNum - 1]
      },
      pageGen(pageNum) {
        return this.links[pageNum - 1].slice(1)
      }
    }
  }
</script>

<!-- b-pagination-nav-links.vue -->
```

## Customizing appearance

`<b-pagination-nav>` supports several props/slots that allow you to customize the appearance. All
`*-text` props are text-only and strip out HTML but you can use their equally named slot
counterparts for that.

For a full list of all available slots see the [Slots](#comp-ref-b-pagination-nav-slots) section
below.

```html
<template>
  <div class="overflow-auto">
    <!-- Use text in props -->
    <b-pagination-nav
      v-model="currentPage"
      :number-of-pages="pagesCount"
      base-url="#"
      first-text="First"
      prev-text="Prev"
      next-text="Next"
      last-text="Last" />

    <!-- Use emojis in props -->
    <b-pagination-nav
      v-model="currentPage"
      :number-of-pages="pagesCount"
      base-url="#"
      first-text="⏮"
      prev-text="⏪"
      next-text="⏩"
      last-text="⏭"
      class="mt-4" />

    <!-- Use HTML and sub-components in slots -->
    <b-pagination-nav
      v-model="currentPage"
      :number-of-pages="pagesCount"
      base-url="#"
      class="mt-4"
    >
      <span class="text-success" slot="first-text">First</span>
      <span class="text-danger" slot="prev-text">Prev</span>
      <span class="text-warning" slot="next-text">Next</span>
      <span class="text-info" slot="last-text">Last</span>
      <div class="d-flex align-items-center h-100" slot="ellipsis-text">
        <b-spinner small type="grow" />
        <b-spinner small type="grow" />
        <b-spinner small type="grow" />
      </div>
    </b-pagination-nav>
  </div>
</template>

<script>
  export default {
    data() {
      return {
        pagesCount: 50,
        currentPage: 1
      }
    }
  }
</script>

<!-- b-pagination-nav-appearance.vue -->
```

## Button Size

Optionally change from the default button size by setting the `size` prop to either `'sm'` for
smaller buttons or `'lg'` for larger buttons.

```html
<template>
  <div class="overflow-auto">
    <div>
      <h6>Small</h6>
      <b-pagination-nav
        v-model="currentPage"
        :number-of-pages="pagesCount"
        base-url="#"
        size="sm"
      />
    </div>

    <div class="mt-3">
      <h6>Default</h6>
      <b-pagination-nav
        v-model="currentPage"
        :number-of-pages="pagesCount"
        base-url="#"
      />
    </div>

    <div class="mt-3">
      <h6>Large</h6>
      <b-pagination-nav
        v-model="currentPage"
        :number-of-pages="pagesCount"
        base-url="#"
        size="lg"
      />
    </div>
  </div>
</template>

<script>
  export default {
    data() {
      return {
        pagesCount: 5,
        currentPage: 1
      }
    }
  }
</script>

<!-- b-pagination-nav-size.vue -->
```

## Alignment

By default the pagination component is left aligned. Change the alignment to `center` or `right`
(`right` is an alias for `end`) by setting the prop `align` to the appropriate value.

```html
<template>
  <div class="overflow-auto">
    <div>
      <h6>Left alignment (default)</h6>
      <b-pagination-nav
        v-model="currentPage"
        :number-of-pages="pagesCount"
        base-url="#"
      />
    </div>

    <div class="mt-3 text-center">
      <h6>Center alignment</h6>
      <b-pagination-nav
        v-model="currentPage"
        :number-of-pages="pagesCount"
        base-url="#"
        align="center"
      />
    </div>

    <div class="mt-3 text-right">
      <h6>Right (end) alignment</h6>
      <b-pagination-nav
        v-model="currentPage"
        :number-of-pages="pagesCount"
        base-url="#"
        align="right"
      />
    </div>
  </div>
</template>

<script>
  export default {
    data() {
      return {
        pagesCount: 5,
        currentPage: 3
      }
    }
  }
</script>

<!-- b-pagination-nav-alignment.vue -->
```

## Small screen support

On smaller screens (i.e. mobile), some of the `<b-pagination-nav>` buttons will be hidden to
minimize the potential of the pagination interface wrapping onto multiple lines:

- The ellipsis indicators will be hidden on screens `xs` and smaller.
- Page number buttons will be limited to a maximum of 3 visible on `xs` screens and smaller.

This ensures that no more than 3 page number buttons are visible, along with the goto _first_,
_prev_, _next_, and _last_ buttons.

## Accessibility

The `<b-pagination-nav>` component provides many features to support assistive technology users,
such as `aria-` attributes and keyboard navigation.

### ARIA labels

`<b-pagination-nav>` provides various `*-label-*` props which are used to set the `aria-label`
attributes on the various elements within the component, which will help users of assistive
technology.

| Prop               | `aria-label` content default                            |
| ------------------ | ------------------------------------------------------- |
| `label-first-page` | "Goto first page"                                       |
| `label-prev-page`  | "Goto previous page"                                    |
| `label-next-page`  | "Goto next page"                                        |
| `label-last-page`  | "Goto last page"                                        |
| `label-page`       | "Goto page", appended with the page number              |
| `aria-label`       | "Pagination", applied to the outer pagination container |

### Keyboard navigation support

`<b-pagination-nav>` supports keyboard navigation out of the box.

- Tabbing into the pagination component will autofocus the current page button
- <kbd>LEFT</kbd> and <kbd>RIGHT</kbd> arrow keys will focus the previous and next buttons in the
  page list, respectively, and <kbd>ENTER</kbd> or <kbd>SPACE</kbd> keys will select (click) the
  focused page button

## See also

For pagination control of a component (such as `<b-table>`), use the
[`<b-pagination>`](/docs/components/pagination) component instead.

<!-- Component reference added automatically from component package.json -->
